@@ -13,29 +13,27 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-import warnings
 from typing import Callable, Dict, Optional, Sequence, Tuple, Union
+import warnings
 
-from google.api_core import grpc_helpers
-from google.api_core import operations_v1
-from google.api_core import gapic_v1
+from google.api import service_pb2  # type: ignore
+from google.api_core import gapic_v1, grpc_helpers, operations_v1
 import google.auth  # type: ignore
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-
+from google.longrunning import operations_pb2  # type: ignore
 import grpc  # type: ignore
 
-from google.api import service_pb2  # type: ignore
-from google.cloud.servicemanagement_v1.types import resources
-from google.cloud.servicemanagement_v1.types import servicemanager
-from google.longrunning import operations_pb2  # type: ignore
-from .base import ServiceManagerTransport, DEFAULT_CLIENT_INFO
+from google.cloud.servicemanagement_v1.types import resources, servicemanager
+
+from .base import DEFAULT_CLIENT_INFO, ServiceManagerTransport
 
 
 class ServiceManagerGrpcTransport(ServiceManagerTransport):
     """gRPC backend transport for ServiceManager.
 
-    `Google Service Management API </service-management/overview>`__
+    `Google Service Management
+    API <https://cloud.google.com/service-infrastructure/docs/overview>`__
 
     This class defines the same methods as the primary client, so the
     primary client can load the underlying transport implementation
@@ -229,8 +227,7 @@ class ServiceManagerGrpcTransport(ServiceManagerTransport):
 
     @property
     def grpc_channel(self) -> grpc.Channel:
-        """Return the channel designed to connect to this service.
-        """
+        """Return the channel designed to connect to this service."""
         return self._grpc_channel
 
     @property
@@ -680,5 +677,9 @@ class ServiceManagerGrpcTransport(ServiceManagerTransport):
     def close(self):
         self.grpc_channel.close()
 
+    @property
+    def kind(self) -> str:
+        return "grpc"
+
 
 __all__ = ("ServiceManagerGrpcTransport",)
